# -*- coding: utf-8 -*-

from benedict.dicts import benedict
from benedict.metadata import (
    __author__, __copyright__, __description__,
    __license__, __title__, __version__,
)
